==> wp.26_72460.2026-02-05_14-16-34.tar.gz: wp-config.php <==
<?php
/** Enable W3 Total Cache */
define('WP_CACHE', true); // Added by W3 Total Cache

/**
 * The base configuration for WordPress
 *
 * The wp-config.php creation script uses this file during the installation.
 * You don't have to use the website, you can copy this file to "wp-config.php"
 * and fill in the values.
 *
 * This file contains the following configurations:
 *
 * * Database settings
 * * Secret keys
 * * Database table prefix
 * * ABSPATH
 *
 * @link https://developer.wordpress.org/advanced-administration/wordpress/wp-config/
 *
 * @package WordPress
 */

// ** Database settings - You can get this info from your web host ** //
/** The name of the database for WordPress */
define( 'DB_NAME', 'wolfit_wp25' );

/** Database username */
define( 'DB_USER', 'wolfit_wp25' );

/** Database password */
define( 'DB_PASSWORD', '8p![rS3@Zl2]i-A9' );

/** Database hostname */
define( 'DB_HOST', 'localhost' );

/** Database charset to use in creating database tables. */
define( 'DB_CHARSET', 'utf8' );

/** The database collate type. Don't change this if in doubt. */
define( 'DB_COLLATE', '' );

/**#@+
 * Authentication unique keys and salts.
 *
 * Change these to different unique phrases! You can generate these using
 * the {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}.
 *
 * You can change these at any point in time to invalidate all existing cookies.
 * This will force all users to have to log in again.
 *
 * @since 2.6.0
 */
define( 'AUTH_KEY',         '3zudvv8yffq3wisis8o5eccioxh4c3cjimcq287vl9rqbjzujro3f87xdqggohso' );
define( 'SECURE_AUTH_KEY',  'ulfkzdrvt55lqhimze98lseidlikt0lgkgyozjv4hoaahfyfqyqweg3yub9hdciz' );
define( 'LOGGED_IN_KEY',    'oyat3pzqagflg1nzxnomdfnwxyorcdcgyxzhb6jrjmw40q2hcnl5yz0uc7jwk2sn' );
define( 'NONCE_KEY',        'p0npeqopd84l0uznjp2pl9ypkuixhiqvrghj5ewixnbln65cjktv0xm11qpumuwn' );
define( 'AUTH_SALT',        'pbpo6qgi5ofxnlwv3qpc6xjkeok75h8fbynrybwoqkf6mbbhhhkw02ecgnwbjxne' );
define( 'SECURE_AUTH_SALT', 'xrkqk9oweqh1fiswgwzfbqwzdffogiowe1klu1f1yvimeqarqypicawvmttf1trz' );
define( 'LOGGED_IN_SALT',   'mstthlzzgsbc27zfidjr1iaj4zyka80ds3upmb2kcrutkmph2aylq7iiletkzlvu' );
define( 'NONCE_SALT',       'mca3zhqjm0v8ztq4xfffawrxhohzdpkvvuxjsxhpdq6sl6vkkzlzvce5mqxqbm9x' );

/**#@-*/

/**
 * WordPress database table prefix.
 *
 * You can have multiple installations in one database if you give each
 * a unique prefix. Only numbers, letters, and underscores please!
 */
$table_prefix = 'wpmn_';

/**
 * For developers: WordPress debugging mode.
 *
 * Change this to true to enable the display of notices during development.
 * It is strongly recommended that plugin and theme developers use WP_DEBUG
 * in their development environments.
 *
 * For information on other constants that can be used for debugging,
 * visit the documentation.
 *
 * @link https://developer.wordpress.org/advanced-administration/debug/debug-wordpress/
 */
define( 'WP_DEBUG', false );

/* Add any custom values between this line and the "stop editing" line. */



/* That's all, stop editing! Happy publishing. */

/** Absolute path to the WordPress directory. */
if ( ! defined( 'ABSPATH' ) ) {
	define( 'ABSPATH', __DIR__ . '/' );
}

/** Sets up WordPress vars and included files. */
require_once ABSPATH . 'wp-settings.php';

==> wp.26_72630.2025-01-10_22-58-18.tar.gz: wp-config.php <==
<?php
/**
 * The base configuration for WordPress
 *
 * The wp-config.php creation script uses this file during the installation.
 * You don't have to use the website, you can copy this file to "wp-config.php"
 * and fill in the values.
 *
 * This file contains the following configurations:
 *
 * * Database settings
 * * Secret keys
 * * Database table prefix
 * * ABSPATH
 *
 * @link https://developer.wordpress.org/advanced-administration/wordpress/wp-config/
 *
 * @package WordPress
 */

// ** Database settings - You can get this info from your web host ** //
/** The name of the database for WordPress */
define( 'DB_NAME', 'autf7216_autoone_serpong' );

/** Database username */
define( 'DB_USER', 'autf7216_autoone_serpong' );

/** Database password */
define( 'DB_PASSWORD', 'Spe.1-S50p' );

/** Database hostname */
define( 'DB_HOST', 'localhost' );

/** Database charset to use in creating database tables. */
define( 'DB_CHARSET', 'utf8mb4' );

/** The database collate type. Don't change this if in doubt. */
define( 'DB_COLLATE', '' );

/**#@+
 * Authentication unique keys and salts.
 *
 * Change these to different unique phrases! You can generate these using
 * the {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}.
 *
 * You can change these at any point in time to invalidate all existing cookies.
 * This will force all users to have to log in again.
 *
 * @since 2.6.0
 */
define( 'AUTH_KEY',         'ftthzoiwhyalosnnaxyydhufxb989cnttpwstornyxf9w3i4cotmzwkh8iifg4th' );
define( 'SECURE_AUTH_KEY',  'pthsfk2mfntfdsezww98ky9kidotg4qjjbreygbngzain0imaaeusndxurs4n3b3' );
define( 'LOGGED_IN_KEY',    'zqyndvsuvdyk44ifwbvjj3kzmmxiqrwvfcissvfcvmp5n7ebvmlxfk23n5iyh5ph' );
define( 'NONCE_KEY',        'gd4pj0fbnz8ecucozdqgajqbxnq1ibrovwv3mig2bcxmptsr7cxmmwltzl7hxowx' );
define( 'AUTH_SALT',        'og1swzauc0y5jzjuwh8h7ruxwzurchdmzmkvar5diibi4jcpdys2nikxibrxrqyh' );
define( 'SECURE_AUTH_SALT', 'qgdazojgwegyfck9r5iw26rcdbcugakcfu1xq1pkoctkmji6trysigrr8hxdesie' );
define( 'LOGGED_IN_SALT',   'rt4wqiuta0mwqdqg2psuhufyrgnjlzev06n67zqd3jhzmo5goenyal16jyhhqlwv' );
define( 'NONCE_SALT',       'rotl16cbjre0asuelohijwualywyvfipurjsecpxg0sqewqm6br9kvwzllc2gbnl' );

/**#@-*/

/**
 * WordPress database table prefix.
 *
 * You can have multiple installations in one database if you give each
 * a unique prefix. Only numbers, letters, and underscores please!
 *
 * At the installation time, database tables are created with the specified prefix.
 * Changing this value after WordPress is installed will make your site think
 * it has not been installed.
 *
 * @link https://developer.wordpress.org/advanced-administration/wordpress/wp-config/#table-prefix
 */
$table_prefix = 'autoone';

/**
 * For developers: WordPress debugging mode.
 *
 * Change this to true to enable the display of notices during development.
 * It is strongly recommended that plugin and theme developers use WP_DEBUG
 * in their development environments.
 *
 * For information on other constants that can be used for debugging,
 * visit the documentation.
 *
 * @link https://developer.wordpress.org/advanced-administration/debug/debug-wordpress/
 */
define( 'WP_DEBUG', false );

/* Add any custom values between this line and the "stop editing" line. */



/* That's all, stop editing! Happy publishing. */

/** Absolute path to the WordPress directory. */
if ( ! defined( 'ABSPATH' ) ) {
	define( 'ABSPATH', __DIR__ . '/' );
}

/** Sets up WordPress vars and included files. */
require_once ABSPATH . 'wp-settings.php';
